<?php
/**
 * @file
 * Ticket Type entity class.
 */

/**
 * Provides an entity class Ticket Type.
 */
class TicketRegistrationEntity extends Entity {

  // Allow access to Ticket Type properties.
  public $trid;
  public $vid;
  // Essentially ttid is the bundle.
  public $bundle;
  public $uid;
  public $status;
  public $created;
  public $changed;

  /**
   * Construct.
   */
  public function __construct(array $values = array()) {
    return parent::__construct($values, 'ticket_registration');
  }

  /**
   * A helper function to get a registration's ticket type entity.
   */
  public function ticket_type() {
    return entity_load_single('ticket_type', $this->bundle);
  }

}

class TicketRegistrationUIController extends EntityDefaultUIController {

  /**
   * Implements hook_menu().
   */
  public function hook_menu() {
    $items = array();
    $id_count = count(explode('/', $this->path));
    $wildcard = isset($this->entityInfo['admin ui']['menu wildcard']) ? $this->entityInfo['admin ui']['menu wildcard'] : '%entity_object';
    $plural_label = isset($this->entityInfo['plural label']) ? $this->entityInfo['plural label'] : $this->entityInfo['label'] . 's';

    foreach (ticket_get_ticket_types() as $ticket_type) {
      $stub_entity = new TicketRegistrationEntity();
      $stub_entity->bundle = $ticket_type->ttid;

      // Individual Ticket registration form. (i.e. entity add).
      // This is likely not needed because we're using the universal
      // ticket register multiple entity form (See ticket.module's
      // hook_menu()).
      $items[$this->path . '/' . $ticket_type->ttid . '/register'] = array(
        'title' => 'Ticket registration',
        'title callback' => 'ticket_registration_label',
        'title arguments' => array($stub_entity),
        'page callback' => 'entity_ui_get_form',
        'page arguments' => array($this->entityType, $stub_entity, 'add'),
        // Anyone who can view a ticket type field, should be able to
        // register for those tickety types.
        'access callback' => 'ticket_type_access',
        'access arguments' => array('view', $ticket_type),
        'file path' => drupal_get_path('module', 'ticket') . '/includes',
        'file' => 'ticket_registration.admin.inc',
        'type' => MENU_LOCAL_ACTION,
      );
    }

    // These were generally taken from the entity module.
    $items[$this->path . '/manage/' . $wildcard] = array(
      'title' => 'Registration',
      'title callback' => 'entity_label',
      'title arguments' => array($this->entityType, $this->id_count + 2),
      'page callback' => 'ticket_registration_view',
      'page arguments' => array($this->entityType, $this->id_count + 2),
      'load arguments' => array($this->entityType),
      'access callback' => 'entity_access',
      'access arguments' => array('view', $this->entityType, $this->id_count + 2),
      'file path' => drupal_get_path('module', 'ticket') . '/includes',
      'file' => 'ticket_registration.admin.inc',
      'type' => MENU_DEFAULT_LOCAL_TASK,
    );
    $items[$this->path . '/manage/' . $wildcard . '/edit'] = array(
      'title' => 'Edit registration',
      'title callback' => 'entity_label',
      'title arguments' => array($this->entityType, $this->id_count + 2),
      'page callback' => 'entity_ui_get_form',
      'page arguments' => array($this->entityType, $this->id_count + 2),
      'load arguments' => array($this->entityType),
      'access callback' => 'entity_access',
      'access arguments' => array('update', $this->entityType, $this->id_count + 2),
      'file path' => drupal_get_path('module', 'ticket') . '/includes',
      'file' => 'ticket_registration.admin.inc',
      'type' => MENU_LOCAL_TASK,
    );

    // Menu item for operations like revert and delete.
    $items[$this->path . '/manage/' . $wildcard . '/%'] = array(
      'page callback' => 'drupal_get_form',
      'page arguments' => array($this->entityType . '_operation_form', $this->entityType, $this->id_count + 2, $this->id_count + 3),
      'load arguments' => array($this->entityType),
      'access callback' => 'entity_access',
      'access arguments' => array('delete', $this->entityType, $this->id_count + 2),
      'file path' => drupal_get_path('module', 'entity') . '/includes',
      'file' => 'entity.ui.inc',
      'type' => MENU_LOCAL_TASK,
    );

    return $items;
  }

}
