<?php
/**
 * @file
 * Ticket state admin file.
 */

/**
 * Implements ENTITY_TYPE_form().
 */
function ticket_state_form($form, &$form_state, $entity, $op = 'edit') {

  // Attach the fields for this ticket registration.
  field_attach_form('ticket_state', $entity, $form, $form_state);

  // Add the property form fields.
  $form['label'] = array(
    '#title' => t('State label'),
    '#description' => t('The name of this ticket registration state.'),
    '#type' => 'textfield',
    '#required' => TRUE,
    '#default_value' => isset($entity->label) ? $entity->label : '',
  );

  $form['name'] = array(
    '#title' => t('State machine name'),
    '#description' => t('The unique machine name of this state. The machine name must only contain lowercase letters, numbers and underscores.'),
    '#type' => 'machine_name',
    '#required' => TRUE,
    '#default_value' => isset($entity->name) ? $entity->name : '',
    '#machine_name' => array(
      'exists' => 'ticket_state_name_exists',
      'source' => array('label'),
    ),
  );

  $form['description'] = array(
    '#title' => t('Description'),
    '#description' => t('A description of this ticket registration state.'),
    '#type' => 'textarea',
    '#required' => FALSE,
    '#default_value' => isset($entity->description) ? $entity->description : '',
  );

  $form['weight'] = array(
    '#title' => t('Weight'),
    '#description' => t('The weight determines the logical order of states.'),
    '#type' => 'weight',
    '#default_value' => isset($entity->weight) ? $entity->weight : 0,
    '#delta' => 10,
  );

  $form['status'] = array(
    '#title' => t('Status'),
    '#description' => t('Set the status to enable or disable this state.'),
    '#type' => 'radios',
    '#options' => array(
      t('Disabled'),
      t('Enabled'),
    ),
    '#required' => TRUE,
    '#default_value' => isset($entity->status) ? $entity->status : 1,
  );

  $form['actions'] = array('#type' => 'actions');
  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => ($op == 'edit') ? t('Update') : t('Save'),
    '#weight' => 40,
  );

  if ($op != 'add' && $op != 'clone') {
    $form['actions']['delete'] = array(
      '#type' => 'submit',
      '#value' => t('Delete'),
      '#weight' => 45,
      '#limit_validation_errors' => array(),
      '#submit' => array('ticket_state_form_submit_delete'),
    );
  }

  return $form;
}

/**
 * Machine name exists callback.
 */
function ticket_state_name_exists($name) {
  return db_select('ticket_state')
    ->condition('name', $name)
    ->countQuery()
    ->execute()
    ->fetchField();
}

/**
 * ENTITY_TYPE_form() submit callback.
 */
function ticket_state_form_submit(&$form, &$form_state) {
  $ticket_state = entity_ui_form_submit_build_entity($form, $form_state);

  // Add info to new states.
  if (empty($ticket_state->tsid)) {
    $ticket_state->is_new = TRUE;
    $ticket_state->created = REQUEST_TIME;
  }

  // Update and save.
  $ticket_state->changed = REQUEST_TIME;
  $ticket_state->save();

  drupal_set_message(t('The ticket registration state %state has been saved.', array('%state' => $ticket_state->label)));
  $form_state['redirect'] = array(ticket_get_admin_path('ticket_state'));
}

/**
 * ENTITY_TYPE_form() delete callback.
 */
function ticket_state_form_submit_delete($form, &$form_state) {
  $form_state['redirect'] = array(
    ticket_get_admin_path('ticket_state') . '/manage/' . $form_state['ticket_state']->tsid . '/delete',
  );
}
